==> cxxtools_2.2.1.orig.tar.gz: cxxtools-2.2.1/src/condition.cpp <==
/*
 * Copyright (C) 2005-2006 by Dr Marc Boris Duerner
 * Copyright (C) 2005-2006 by Sebastian Pieck
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "conditionimpl.h"
#include "cxxtools/condition.h"

namespace cxxtools {

Condition::Condition()
{
    _impl = new ConditionImpl();
}


Condition::~Condition()
{
    delete _impl;
}


void Condition::wait(Mutex& mtx)
{
   _impl->wait(mtx);
}


bool Condition::wait(Mutex& mtx, unsigned int ms)
{
    return _impl->wait(mtx, ms);
}


void Condition::signal()
{
    _impl->signal();
}


void Condition::broadcast()
{
    _impl->broadcast();
}

} // !namespace cxxtools

==> cxxtools_3.0.0.orig.tar.gz: cxxtools-3.0/src/condition.cpp <==
/*
 * Copyright (C) 2005-2006 by Dr Marc Boris Duerner
 * Copyright (C) 2005-2006 by Sebastian Pieck
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "conditionimpl.h"
#include "cxxtools/condition.h"

namespace cxxtools {

Condition::Condition()
{
    _impl = new ConditionImpl();
}


Condition::~Condition()
{
    delete _impl;
}


void Condition::wait(Mutex& mtx)
{
   _impl->wait(mtx);
}


bool Condition::wait(Mutex& mtx, const Milliseconds& ts)
{
    return _impl->wait(mtx, ts);
}


void Condition::signal()
{
    _impl->signal();
}


void Condition::broadcast()
{
    _impl->broadcast();
}

} // !namespace cxxtools
